@@ -193,17 +193,13 @@ function proon_scaled_singles($rawvalue, $default_suffix) {
   return $tally;
 }
 
-function proon_push_foldername($word, $foldername) {
-  return $word . '_' . bin2hex($foldername);
-}
-
 function proon_pull_foldername($key) {
   list($word, $foldername) = explode('_', $key);
-  return hex2bin($foldername);
+  return base64_decode($foldername);
 }
 
 function proon_encode_foldername($folder) {
-  return bin2hex($folder);
+  return base64_encode($folder);
 }
 
 function proon_arrays_differ(&$a, &$b) {
